#
# spec file for package tgt
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

Name:           tgt
Version:        1.0.74
Release:        150400.1.4
Summary:        Generic Linux target framework (tgt)
License:        GPL-2.0-only
Group:          System/Daemons
URL:            http://stgt.sourceforge.net/
Source:         https://github.com/fujita/%{name}/archive/v%{version}.tar.gz
Source1:        %{name}d.service
Source4:        sysconfig.%{name}
Patch1:         %{name}-fix-build
Patch2:         setup-tgt-conf-d.patch
Patch3:         %{name}-include-sys-macros-for-major.patch
Patch4:         %{name}-Fix-gcc7-string-truncation-warnings.patch
Patch5:	harden_tgtd.service.patch
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  libaio-devel
BuildRequires:  libxslt
BuildRequires:  openssl-devel
BuildRequires:  perl-Config-General
BuildRequires:  systemd-rpm-macros
Requires:       perl-Config-General
Requires(pre):  %fillup_prereq
Obsoletes:      iscsitarget

%description
Linux target framework (tgt) aims to simplify various SCSI target
driver (iSCSI, Fibre Channel, SRP, etc) creation and maintenance.

Tgt consists of kernel modules, user-space daemon, and user-space
tools. Some target drivers uses all of them and some use only
user-space daemon and tools (i.e. they completely runs in user space).

%prep
%setup -q
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1

%build
%ifarch ppc ppc64 ppc64le
%define backends ISCSI=1 FCP=1 FCOE=1 IBMVIO=1
%else
%define backends ISCSI=1 FCP=1 FCOE=1
%endif
make OPTFLAGS="%{optflags}" %{backends}

%install
make DESTDIR=%{buildroot} docdir=%{_docdir}/%{name} install
install -vD -m 644 %{SOURCE1} %{buildroot}/%{_unitdir}/%{name}d.service
install -vD %{SOURCE4} %{buildroot}%{_fillupdir}/sysconfig.%{name}
ln -sf service %{buildroot}/%{_sbindir}/rc%{name}d

%pre
%service_add_pre %{name}d.service

%post
%fillup_only
%service_add_post %{name}d.service

%preun
%service_del_preun %{name}d.service

%postun
%service_del_postun %{name}d.service

%files
%defattr(-,root,root)
%{_sbindir}/*
%dir %{_sysconfdir}/tgt
%dir %{_sysconfdir}/tgt/conf.d
%config %attr(0644,root,root) %{_sysconfdir}/tgt/targets.conf
%{_fillupdir}/sysconfig.tgt
%{_unitdir}/%{name}d.service
%doc README doc/README.iscsi doc/README.iser doc/README.lu_configuration
%doc doc/README.mmc doc/README.passthrough doc/README.sbcjukebox doc/README.ssc
%doc doc/README.rbd doc/tmf.txt
%doc %_defaultdocdir/%name/examples
%doc %_defaultdocdir/%name/html
%{_mandir}/man5/*
%{_mandir}/man8/*

%changelog
* Wed Nov 24 2021 jsegitz@suse.com
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_tgtd.service.patch
  Modified:
  * tgtd.service
* Fri Jul 26 2019 matthias.gerstner@suse.com
- removal of SuSEfirewall2 service, since SuSEfirewall2 has been replaced by
  firewalld, see [1].
  [1]: https://lists.opensuse.org/opensuse-factory/2019-01/msg00490.html
* Fri Feb 15 2019 lduncan@suse.com
- Update to version v1.0.74 from version v1.0.60:
  * tgt 1.0.74
  * AIO backing store now reports a list of supported opcodes
  * tgt 1.0.73
  * Update tgt-admin
  * fix build w/newer glibc
  * Display nop_count and and nop_interval
  * Quote $backing_store variable in system(), execute() and
    backtick-calls
  * Buffer size is stored in struct concat_buf.size field, so
    use that instead of BUFSIZE since buffer size can be more
    than BUFSIZE. Also, remove BUFSIZE since its not used anymore.
  * tgt 1.0.72
  * smc: fix snprintf warnings with gcc7
  This removed the tarball v1.0.60.tar.gz, and replaced it
  with v1.0.74.tar.gz, which can now be gotten using the new
  _service file. This also updated the SPEC file with the new
  version number and the different patch set. Remaining
  patches were renumbered.
  This following patches were UPDATED (refreshed):
  * tgt-fix-build
  * tgt-include-sys-macros-for-major.patch
  The following patches were REMOVED (no longer needed):
  * tgt-handle-access-of-a-target-that-has-been-removed
  * tgt-missing-module-directory-not-an-error
  * tgt-compare-pointer-to-null.patch
  And the following patch was added (and submitted upstream):
  * tgt-Fix-gcc7-string-truncation-warnings.patch
* Sun Aug 12 2018 lduncan@suse.com
- Fixing build issue with "major()" and a pointer
  comparison warning while I was at it, adding patches (bsc#1181571):
  * tgt-include-sys-macros-for-major.patch
  * tgt-compare-pointer-to-null.patch
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Tue Jan 31 2017 lduncan@suse.com
- Adding documentation files to SPEC file to
  silence rpmlint
* Mon Nov 16 2015 lduncan@suse.com
- Adding upstream patch to silence bogus error
  message when backing-store directory not present
  (bsc#954801), adding patch:
  * tgt-missing-module-directory-not-an-error
* Mon Nov 16 2015 lduncan@suse.com
- Added upstream patch to handle possible target removal
  while accessing it (bsc#922526), adding patch:
  * tgt-handle-access-of-a-target-that-has-been-removed
* Fri Sep 18 2015 p.drouand@gmail.com
- Update to version 1.0.60
  * No changelog available
- Update homepage Url
- Use download Url as source
- Remove tgt-git-update; fixed on upstream
- Remove depreciated AUTHORS section
- Perform a spec-cleaner on spec file
* Sun Sep 13 2015 ddiss@suse.com
- Fix rctgtd systemd service symlink; (bnc#945604).
* Thu Sep 10 2015 bwiedemann@suse.com
- Allow to add options via sysconfig (bnc#828214)
- Drop invalid ExecStopPre entry
* Fri Jun 26 2015 bwiedemann@suse.com
- fix tgtd start by giving tgtd time to open the socket (bnc#934642)
  and use bash to run multiple programs in ExecStartPost
* Tue Sep  2 2014 mls@suse.de
- support ppc64le
* Wed May 14 2014 meissner@suse.com
- add missed %%service_add_pre in %%pre section
* Wed Feb 26 2014 hare@suse.de
- Update to latest upstream version 1.0.44 (FATE#316717):
  * Add sheepdog support
  * Add rbd support
  * Update iSER support
  * Add support for iSCSI NOP-OUT
  * SPC/SBC fixes
  * iSCSI fixes
  * Fixup persistent group reservations
- Removed tgt-mgmt-fixed-m-system-o-delete-handling.patch:
  Merged with upstream
- Removed tgt-1.0.28.tar.bz2
- Added tgt-1.0.44.tar.bz2
* Tue Jan 28 2014 werner@suse.de
- Make service link a local one
* Wed Oct 23 2013 p.drouand@gmail.com
- Drop sysvinit support
- Add systemd support
* Sat Jul 13 2013 dmueller@suse.com
- add setup-tgt-conf-d.patch: Configure a /etc/tgt/conf.d by default
- move examples to docdir
* Thu Apr 11 2013 lduncan@suse.com
- Renamed firewall service file from iscsitarget to tgt
  to remove conflict with tgt package (bnc#814364)
* Fri Oct 26 2012 lduncan@suse.com
- Add tgt-mgmt-fixed-m-system-o-delete-handling.patch: Fixes
  shutdown hang (bnc#767438)
- Removed PIDFILE completely from init file, as it is not used
* Tue Jul 10 2012 cfarrell@suse.com
- license update: GPL-2.0
  Most of the source code files carry a GPL-2.0 notice, not GPL-2.0+
* Thu Jun 14 2012 vuntz@opensuse.org
- Remove "# pidfile: /var/run/tgtd.pid" from tgt.init, as it makes
  the script hang on systemd-based systems. This is the same bug as
  rh#797913, and the fix was used in Fedora. Apparently, there's no
  such pid file written by tgtd.
* Mon Jun  4 2012 hare@suse.de
- Update to latest upstream release 1.0.23
  * Improved SCSI emulation
  * Various small fixes
* Mon Sep 21 2009 dmueller@suse.de
- require perl-Config-General (bnc#474129)
- add rc-symlink (bnc#474136)
* Thu Oct  9 2008 hare@suse.de
- Update to latest upstream release 0.9.0
  * tgt-admin fixes
  * add null backing store
  * Improve iSER scheduling
  * Various small fixes
* Mon Sep 15 2008 hare@suse.de
- Include fixes from upstream:
  * Add support to update targets
  * tgtadm fixes
  * Add PREVENT ALLOW MEDIA REMOVAL to ssc
  * Add MANAGEMENT PROTOCOL IN to ssc
  * Update README
- Fix rpmlint errors
* Fri Aug  8 2008 hare@suse.de
- Update to latest released version 20080805
  * Include FCP backend
  * Include FCoE backend
  * Bugfixes
* Thu Aug  9 2007 olh@suse.de
- remove inclusion of linux/hash.h, include it directly
* Wed Apr  4 2007 hare@suse.de
- Added service definition for SUSEFirewall2 (#251679)
* Wed Apr  4 2007 hare@suse.de
- Initial version svn r849
- Update to latest git version
- Fixes for build on openSUSE
